import { Component, OnInit } from '@angular/core';
import {  Router, ActivatedRoute } from '@angular/router';
import * as _ from 'lodash';
import { CommonService, StoreService } from 'services';
import { UserApi, CommonApi, ShopApi, OrderApi, PayApi, User } from 'client';

const WeixinJSBridge = window['WeixinJSBridge'];



const orderDefault = {
    id: '',
    orderNum: '',
    shopName: '',
    shopNum: '',
    money: '',
    needInvoice: 1,
    title: '',
    address: '',
    shopId: ''
};

@Component({
  selector: 'store-init-order',
  templateUrl: './store-init-order.component.html',
  styleUrls: ['./store-init-order.component.scss'],
  providers: [CommonService, StoreService, CommonApi, ShopApi, OrderApi, PayApi]
})
export class StoreInitOrderComponent implements OnInit {

  public storeOrderInfo: any = _.cloneDeep(orderDefault);
  public shopId: number;
  public pay: number;
  public shopOrderId: number;
  public showVcodeWin: boolean = false;

  // wx
  public openId: any;
  public orderId: any;
  public wxData: any = {
      appId: '',
      timeStamp: '',
      nonceStr: '',
      package: '',
      signType: '',
      paySign: ''
  };
  public urlState: any = {};
  public urlParams: any;


  

  // 订单信息窗口
  public showOrderInfoWin: boolean = false;

  constructor(
    private router: Router,
    private route: ActivatedRoute,
    private cApi: CommonApi,
    private sApi: ShopApi,
    private oApi: OrderApi,
    private cs: CommonService,
    private ss: StoreService,
    private pApi: PayApi
  ) {

  }

  public ngOnInit() {
    let shopid = localStorage.getItem('shopId');
    let paystatus = localStorage.getItem('shopPay');
    let shopOrderId = localStorage.getItem('shopOrderId');
    let token = localStorage.getItem('token');
    this.route.queryParams.subscribe((data) => {
        this.urlParams = data;
        if (data['openId']) {
            this.openId = data['openId'];
            alert('OpenId: ' + this.openId);
        }
        if (data['params']) {
            this.urlState = this.parseUrlFieldPrams(data['params']);
            alert('urlState: ' + this.urlState);
        }
    });

    if (!token) {
      this.cs.gotoLoginPage(this.router);
      return;
    }
    this.shopId = shopid === null ? undefined : Number(shopid);
    this.pay = paystatus === null ? undefined : Number(paystatus);
    this.shopOrderId = shopOrderId === null ? undefined : Number(shopOrderId);
    this.sApi.defaultHeaders.set('token', token);
    this.oApi.defaultHeaders.set('token', token);
    this.pApi.defaultHeaders.set('token', token);

    if (this.shopId && this.shopOrderId) {
      this.getShopOrderInfo(this.shopOrderId);
    }
  }

  public onDownLoad() {

  }



  /**
   * 订单 - 取消订单
   * 
   * @param {any} id
   * 
   * @memberOf StoreInitComponent
   */
  public onCancelOrder(id) {
    this.oApi.orderCarMobileIdDeleteDelete(String(id)).subscribe((data) => {
      if (data.meta.code === 200) {
        this.storeOrderInfo = _.cloneDeep(orderDefault);
        this.showOrderInfoWin = false;
        localStorage.removeItem('shopOrderId');
      } else {
        this.cs.responseErrorHandler(data);
      }
    }, (err) => console.error(err));
  }

  /**
   * 订单 - 支付订单
   * 
   * @param {any} id
   * 
   * @memberOf StoreInitComponent
   */
  public onPayOrder() {
    // alert('haha');
      // alert(WeixinJSBridge);
    this.pApi.paymentWeChatPayPost(Number(this.shopOrderId), String(this.openId), 1).subscribe((data) => {
        if (data.meta.code === 200) {
            // alert('ajax 200');
            // alert('data.data: ' + JSON.stringify(data.data));
            this.wxData.appId = data.data.appId;
            // alert('this.wxData.appId: ' + this.wxData.appId);
            this.wxData.package = data.data.package;
            // alert('this.wxData.package: ' + this.wxData.package);
            this.wxData.nonceStr = data.data.nonceStr;
            // alert('this.wxData.nonceStr: ' + this.wxData.nonceStr);
            this.wxData.timeStamp = data.data.timeStamp + '';
            // alert('this.wxData.timeStamp: ' + this.wxData.timeStamp);
            this.wxData.signType = data.data.signType;
            // alert('this.wxData.signType: ' + this.wxData.signType);
            this.wxData.paySign = data.data.paySign;
            // alert('this.wxData.paySign: ' + this.wxData.paySign);
            
            
            
            
            
            
            this.callWxPay();
        } else {
            alert('ajax error');
        }
    }, (err) => console.error(err));

  }

  

  // 临时支付 假的
  // public onPayOrderTemp(orderid, shopid) {
  //   this.oApi.paymentWeChatPayPost(Number(orderid), String(shopid), 1).subscribe((data) => {
  //     if (data.meta.code === 200) {
  //       localStorage.setItem('shopPay', '2');
  //       this.showOrderInfoWin = false;
  //       this.showVcodeWin = true;
  //     } else {
  //       this.cs.responseErrorHandler(data, false, this.router);
  //     }
  //   }, (err) => console.error(err));
  // }


  /**
   * 编辑初始门店时，获取订单信息
   * 
   * @private
   * @param {any} orderId
   * 
   * @memberOf StoreInitComponent
   */
  private getShopOrderInfo(orderId) {
    this.oApi.orderCarMobileOrderIdGet(Number(orderId)).subscribe((data) => {
      if (data.meta.code === 200 && data.data) {
        this.storeOrderInfo = Object.assign(this.storeOrderInfo, data.data);
        this.showOrderInfoWin = true;
      } else {
        this.cs.responseErrorHandler(data, false, this.router);
      }
    }, (err) => console.error(err));
  }

  // 调起微信支付面板
  private callWxPay() {
    alert('callWxPay func...');
    if (typeof WeixinJSBridge === 'undefined') {
        alert('WeixinJSBridge is undefined');
        if ( document.addEventListener ){
            document.addEventListener('WeixinJSBridgeReady', this.jsApiCall, false);
        }else if (document['attachEvent']){
            document['attachEvent']('WeixinJSBridgeReady', this.jsApiCall); 
            document['attachEvent']('onWeixinJSBridgeReady', this.jsApiCall);
        }
    }else{
        this.jsApiCall();
    }
  }
  private jsApiCall() {
    alert('jsApiCall');
    WeixinJSBridge.invoke(
        'getBrandWCPayRequest',
        this.wxData,
        (res) => {
        // alert("res.err_msg:"+res.err_msg);
            if (res.err_msg == "get_brand_wcpay_request：ok" ) {
            // alert("支付成功！");
                alert('支付成功！');
                localStorage.setItem('shopPay', '2');
                // this.showOrderInfoWin = false;
                // this.showVcodeWin = true;
                // window.location.href="<%=path %>/weiXinTest/accomplishPay?err_msg=" + res.err_msg ;
            }     // 使用以上方式判断前端返回,微信团队郑重提示：res.err_msg将在用户支付成功后返回    ok，但并不保证它绝对可靠。 
        }
    );
  }

  /**
   * 解析参数字段
   * 
   * @private
   * @param {string} parmas
   * @returns
   * 
   * @memberOf StoreInitOrderComponent
   */
  private parseUrlFieldPrams(parmas: string) {
    let paramsObj = parmas.split('@');
    let ret: any = {};
    paramsObj.forEach((val) => {
        let temp = val.split('-');
        ret[temp[0]] = temp[1];
    });
    return ret;
  }

}
