import { Component, OnInit, OnDestroy } from '@angular/core';
import {  Router, ActivatedRoute } from '@angular/router';
import * as _ from 'lodash';
import { CommonService, StoreService, MxUtilService } from 'services';
import { UserApi, CommonApi, ShopApi, OrderApi, PayApi,  User } from 'client';
import { CAN_WX_PAY } from 'consts';

const orderDefault = {
    id: '',
    orderNum: '',
    shopName: '',
    shopNum: '',
    money: '',
    needInvoice: 1,
    title: '',
    address: '',
    shopId: ''
};

@Component({
  selector: 'store-init',
  templateUrl: './store-init.component.html',
  styleUrls: ['./store-init.component.scss'],
  providers: [StoreService, CommonApi]
})
export class StoreInitComponent implements OnInit {

  public store: any = {
    id: '',
    orderId: '',
    name: '',
    provinceId: '',
    cityId: '',
    address: '',
    manager: '',
    tel: '',
    serviceType: '',
    shopNum: 1,
    money: 999
  };
  public storeOrderInfo: any = _.cloneDeep(orderDefault);
  public serviceLists: any[] = [];
  public provinceList: any[] = [];
  public cityList: any[] = [];
  public errorMsg: string = '';
  public shopId: number;
  public pay: number;
  public shopOrderId: number;
  public buyServiceTypes: any[] = [];

  // 二维码窗口
  public showVcodeWin: boolean = false;

  // 订单信息窗口
  public showOrderInfoWin: boolean = false;

  private submitting: boolean = false;
  constructor(
    private router: Router,
    public route: ActivatedRoute,
    private cApi: CommonApi,
    private sApi: ShopApi,
    private oApi: OrderApi,
    private cs: CommonService,
    private ss: StoreService,
    private pApi: PayApi,
    private mus: MxUtilService
  ) {

  }

  public ngOnInit() {
    this.initServiceList(this.ss.getStoreServiceList());
    this.buyServiceTypes = this.ss.getStoreBuyServiceList();
    this.getProvinces();
    let shopid = localStorage.getItem('shopId');
    let token = localStorage.getItem('token');
    if (!token) {
      this.cs.gotoLoginPage(this.router);
      return;
    }
    this.shopId = shopid === null ? undefined : Number(shopid);

    if (this.shopId) {
      this.getShopInfo(this.shopId);
    }
  }

  /**
   * 选择服务项目
   * 
   * @param {any} service
   * @param {any} evt
   * 
   * @memberOf StoreInitComponent
   */
  public onChangeService(service, evt) {
    service.checked = evt;
    this.errorMsg = '';
    this.store.serviceType = this.serviceLists.filter((item) => item.checked).map((item) => item.id).join(',');
  }

  public onNeedInvoiceChange() {
    this.store.needInvoice = this.store.needInvoice === 2 ? 1 : 2;
    if (this.store.needInvoice === 2) {
      setTimeout(() => {
        document.getElementById('storeInitForm').scrollTop = document.getElementById('storeInitForm').scrollHeight;
      }, 100);
    }
  }

  /**
   * 根据省份的改变，获取新的城市列表
   * 
   * @param {any} store
   * @param {any} evt
   * 
   * @memberOf StoreInitComponent
   */
  public onChangeProvince(store, evt) {
    store.provinceId = evt;
    this.errorMsg = '';
    store.cityId = '';
    if (store.provinceId === '') {
      this.cityList = [];
    } else {
      this.getCities(store.provinceId);
    }
  }

  /**
   * 输入型字段获取焦点
   * 
   * 
   * @memberOf StoreInitComponent
   */
  public onFieldFocus() {
    this.errorMsg = '';
  }

  /**
   * 提交订单
   * 
   * 
   * @memberOf StoreInitComponent
   */
  public saveStore() {
    if (this.submitting) {
      return;
    }
    if (this.checkStoreFormInfo()) {

      this.store.id = this.store.id || null;
      this.store.orderId = this.store.orderId || null;

      let saveStore = _.cloneDeep(this.store);
      saveStore.provinceId = Number(saveStore.provinceId);
      saveStore.cityId = Number(saveStore.cityId);
      delete saveStore.shopNum;
      saveStore.viewKey = this.ss.getStoreBuyServiceKey(saveStore.money);
      this.submitting = true;

      this.sApi.shopCarMobileFirstShopPost(saveStore).subscribe((data) => {
        if (data.meta.code === 200) {
          localStorage.setItem('shopId', String(data.data.id));
          if (CAN_WX_PAY) {
            this.cs.requestOpenIdURL(data.data.orderId, 'storeInit');
          } else {
            this.router.navigate([`/storeorder`], {queryParams: {
              openId: '1233',
              orderId: String(data.data.orderId),
              shopId: String(data.data.id),
              source: 'storeInit'
            }});
          }
        } else {
          this.errorMsg = this.cs.responseErrorHandler(data, false, this.router);
        }
      }, (err) => console.error(err), () => {
        this.submitting = false;
      });
    }
  }

  /**
   * 城市切换
   */
  public onChangeCity(store, evt) {
      store.cityId = evt;
      this.errorMsg = '';
  }

  /**
   * 初始化服务项目
   * 为服务项目添加`checked`属性
   * 
   * @private
   * @param {any} services
   * 
   * @memberOf StoreInitComponent
   */
  private initServiceList(services) {
    this.serviceLists = services;
    this.serviceLists.forEach( (item) => item.checked = false );
  }

  /**
   * 获取省份
   * 
   * @private
   * 
   * @memberOf StoreInitComponent
   */
  private getProvinces() {
    this.cApi.commonRegionProvinceGet().subscribe((data) => {
        if (data.meta.code === 200) {
            this.provinceList = data.data;
        } else {
            this.cs.responseErrorHandler(data);
        }
    }, (err) => console.error(err));
  }

  /**
   * 获取城市
   * 
   * @private
   * @param {any} id
   * 
   * @memberOf StoreInitComponent
   */
  private getCities(id) {
    this.cApi.commonRegionProvinceIdCityGet(Number(id)).subscribe((data) => {
        if (data.meta.code === 200) {
            this.cityList = data.data;
        } else {
            this.cs.responseErrorHandler(data);
        }
    }, (err) => console.error(err));
  }

  /**
   * 验证门店表单各字段
   * 
   * @private
   * @returns {boolean}
   * 
   * @memberOf StoreInitComponent
   */
  private checkStoreFormInfo(): boolean {
    let mobileReg = /^(13[0-9]|15[012356789]|17[0135678]|18[0-9]|14[57])[0-9]{8}$/;
    let { name, provinceId, cityId, address, manager, tel, serviceType } = this.store;
    name = name.trim();
    if (name === '') {
      this.errorMsg = '请输入门店名称';
      return false;
    }
    provinceId = String(provinceId).trim();
    cityId = String(cityId).trim();
    address = address.trim();
    if (provinceId === '' || cityId === '' || address === '') {
      this.errorMsg = '请完善门店地址';
      return false;
    }
    manager = manager.trim();
    if (manager === '') {
      this.errorMsg = '请输入负责人';
      return false;
    }
    tel = tel.trim();
    if (tel === '') {
      this.errorMsg = '请输入联系方式';
      return false;
    }
    if (!(this.mus.isPhoneNumber(tel) || this.mus.isHandFreePhoneNumber(tel))) {
        this.errorMsg = '请输入正确的联系方式';
        return false;
    }
    serviceType = serviceType.trim();
    if (serviceType === '') {
      this.errorMsg = '请选择服务类型';
      return false;
    }
    this.store = Object.assign(this.store, { name, provinceId, cityId, address, manager, tel, serviceType });
    this.errorMsg = '';
    return true;
  }

  /**
   * 通过门店id获取门店信息
   * 
   * @private
   * @param {any} shopid
   * 
   * @memberOf StoreInitComponent
   */
  private getShopInfo(shopid) {
    this.sApi.shopCarMobileFirstShopInfoGet(shopid).subscribe((data) => {
      if (data.meta.code === 200) {
        this.store = Object.assign({}, this.store, data.data);
        this.changeServiceTypes();
        this.getCities(this.store.provinceId);
      } else {
        this.cs.responseErrorHandler(data, true, this.router);
      }
    }, (err) => console.error(err));
  }

  /**
   * 编辑门店时，初始化服务类型
   * 
   * @private
   * 
   * @memberOf StoreInitComponent
   */
  private changeServiceTypes() {
    let types = this.store.serviceType.split(',');
    this.serviceLists.forEach((item) => {
      item.checked = _.includes(types, String(item.id)) ? true : false;
    });
  }

}
