import { Component, OnInit, OnDestroy, NgZone, AfterContentInit, AfterViewInit } from '@angular/core';
import {  Router, ActivatedRoute } from '@angular/router';
import * as _ from 'lodash';
import { CommonService } from 'services';

@Component({
  selector: 'mx-award-turnplate',
  templateUrl: './turnplate.component.html',
  styleUrls: ['./turnplate.component.scss'],
  providers: [CommonService]
})
export class MxAwardTurnplateComponent implements OnInit, AfterViewInit, OnDestroy {
    public plateState: string = 'normal';
    public prize: number = 0;
    public prizeIdx: number = 0;
    public styles = {
        transform: 'rotate(0deg)'
    };
    private rotating: boolean = false;
    private platedom;
    private zone;
    private transition: string = 'transitionend';

    constructor(
        private router: Router,
        public route: ActivatedRoute,
        private cs: CommonService
    ) {
        this.zone = new NgZone({ enableLongStackTrace: false });
    }

    public ngOnInit() {
        this.plateState = 'normal';
        this.prize = 0;
        this.prizeIdx = 0;
    }
    public ngAfterViewInit() {
        this.platedom = document.getElementById('turnplate-plate');
        this.transition = typeof document.body.style['transition'] === 'string' ? 'transitionend' : 'webkitTransitionEnd';
        if (this.platedom) {
            this.platedom.addEventListener(this.transition, () => {
                this.prize = this.prizeIdx;
            });
        }
    }

    public ngOnDestroy() {
        if (this.platedom) {
            this.platedom.removeEventListener(this.transition);
        }
    }

    public onGetPrize() {
        if (this.rotating) { return; }
        this.rotating = true;
        setTimeout(() => {
            this.zone.run(() => {
                let rnd = Math.random() * 10;
                this.styles = { transform: 'rotate(0deg)' };
                if (rnd <= 1) {
                    // 10元 现金抵扣券
                    this.styles.transform = 'rotate(3006deg)';
                    this.prizeIdx = 3;
                } else if (rnd <= 4) {
                    // 免费补胎券
                    this.styles.transform = 'rotate(3078deg)';
                    this.prizeIdx = 4;
                } else if (rnd <= 7) {
                    // 20元 机油
                    this.styles.transform = 'rotate(3186deg)';
                    this.prizeIdx = 2;
                } else {
                    // 20元 换轮
                    this.styles.transform = 'rotate(2934deg)';
                    this.prizeIdx = 1;
                }
            });
        }, 0);
    }

   



}
