import { Component, OnInit, OnDestroy } from '@angular/core';
import {  Router, ActivatedRoute } from '@angular/router';
import * as _ from 'lodash';
import { CommonService, StoreService } from 'services';
import { UserApi } from 'client';



@Component({
    selector: 'account-info',
    templateUrl: './info.component.html',
    styles: [require('./info.component.scss')],
    providers: [CommonService]
})
export class AccountInfoComponent implements OnInit {
    public menu = {
        show: false
    };

    public account: any = {
        id: 1,
        mobile: ''
    }

    private token: string = '';

    constructor(
        private router: Router,
        private route: ActivatedRoute,
        private cs: CommonService,
        private uApi: UserApi
    ) {

    }

    public ngOnInit() {
        this.token = localStorage.getItem('token') || '';
        if (this.token) {
            this.getAccountInfo();
        }
    }


    /**
     * 显示主菜单
     * 
     * 
     * @memberOf ReportComponent
     */
    public onShowMenu() {
        this.menu.show = true;
    }

    /**
     * 跳转到修改密码页
     * 
     * 
     * @memberOf AccountInfoComponent
     */
    public onModifyPwd() {
        if (this.account.id) {
            this.router.navigate([`/dashboard/account/pwd/${this.account.id}`]);
        }
    }

    /**
     * 获取账户信息
     * 
     * @private
     * 
     * @memberOf AccountInfoComponent
     */
    private getAccountInfo() {
        this.uApi.userCarMobileMeGet(this.token).subscribe((data) => {
            if (data.meta.code === 200) {
                this.account = data.data;
            } else {
                this.cs.responseErrorHandler(data, true, this.router);
            }
        }, (err) => console.error(err));
    }

}
