import { Component, OnInit, OnDestroy } from '@angular/core';
import {  Router, ActivatedRoute } from '@angular/router';
import * as _ from 'lodash';
import { CommonService, MxUtilService } from 'services';
import { UserApi } from 'client';
import { Md5 } from 'ts-md5/dist/md5';



@Component({
    selector: 'account-pwd',
    templateUrl: './pwd.component.html',
    styles: [require('./pwd.component.scss')],
    providers: [CommonService, MxUtilService, Md5]
})
export class AccountPwdComponent implements OnInit {
    public menu = {
        show: false
    };

    public account: any = {
        oldPassword: '',
        password: '',
        rePassword: ''
    };
    public errorMsg: string = '';

    private token: string = '';
    private submitting: boolean = false;

    constructor(
        private router: Router,
        private route: ActivatedRoute,
        private cs: CommonService,
        private mus: MxUtilService,
        private uApi: UserApi
    ) {

    }

    public ngOnInit() {
        
    }


    /**
     * 显示主菜单
     * 
     * 
     * @memberOf ReportComponent
     */
    public onShowMenu() {
        this.menu.show = true;
    }

    /**
     * 字段获取焦点
     * 
     * 
     * @memberOf AccountPwdComponent
     */
    public onFieldFocus() {
        this.errorMsg = '';
    }

    /**
     * 去账户信息页
     * 
     * 
     * @memberOf AccountPwdComponent
     */
    public gotoAccountInfoPage() {
        this.router.navigate([`/dashboard/account/info`]);
    }

    /**
     * 保存更改
     * 
     * @returns 
     * 
     * @memberOf AccountPwdComponent
     */
    public onSave() {
        if (this.submitting) { return; }
        if (!this.validateFormInfo()) { return; }
        let oldPassword = Md5.hashStr(this.account.oldPassword.trim(), false).toString();
        let password = Md5.hashStr(this.account.password.trim(), false).toString();
        let rePassword = Md5.hashStr(this.account.rePassword.trim(), false).toString();
        this.submitting = true;
        this.uApi.userCarMobileChangePwdPost(oldPassword, password, rePassword).subscribe((data) => {
            if (data.meta.code === 200) {
                this.gotoAccountInfoPage();
            } else {
                this.errorMsg = this.cs.responseErrorHandler(data, false, this.router);
            }
        }, (err) => console.error(err), () => {
            this.submitting = false;
        });
    }


    /**
     * 验证表单字段
     * 
     * @private
     * @returns {boolean} 
     * 
     * @memberOf AccountPwdComponent
     */
    private validateFormInfo(): boolean {
        let { oldPassword, password, rePassword } = this.account;

        if (this.mus.isEmptyString(oldPassword)) {
            this.errorMsg = '密码不能为空';
            return false;
        }
        if (!this.mus.isPassword(oldPassword)) {
            this.errorMsg = '请输入由6~16位的英文字母、数字或符号组成的密码';
            return false;
        }
        if (this.mus.isEmptyString(password)) {
            this.errorMsg = '密码不能为空';
            return false;
        }
        if (!this.mus.isPassword(password)) {
            this.errorMsg = '请输入由6~16位的英文字母、数字或符号组成的密码';
            return false;
        }
        if (this.mus.isEmptyString(rePassword)) {
            this.errorMsg = '密码不能为空';
            return false;
        }
        if (!this.mus.isEqualString(password, rePassword)) {
            this.errorMsg = '两次密码输入不一致';
            return false;
        }
        this.errorMsg = '';
        return true;
    }


}
