import {
  Component,
  OnInit,
  OnDestroy,
  ElementRef,
  Renderer,
} from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import { DefaultApi, ShopApi } from 'client';
import { CommonService, StoreService } from 'services';
import { MxSubAccount, MxStoreResponseItem } from 'interfaces';

import * as _ from 'lodash';
import * as Swiper from 'swiper';
import * as echarts from 'echarts';

@Component({
  selector: 'report-store',
  templateUrl: './report-store.component.html',
  styles: [require('swiper/dist/css/swiper.css'), require('./report-store.component.scss')],
  providers: [StoreService]
})
export class ReportStoreComponent implements OnInit, OnDestroy {
  public slider: any;
  public menu = {
    show: false
  };

  public colors = ['transparent', '#7d6896', '#e5955a', '#6fb7e6', '#538dbc', '#f8a65f', '#cb6762', '#abc370', '#af69e2', '#4ed6dd', '#a13faf', '#db6b94', '#f98480', '#00b6bd', '#f94b4b', '#e533ff', '#dd7026', '#d31818', '#34d146', '#60e8b3'];

  public shopStr: string = '';
  public stores: MxStoreResponseItem[] = [];
  // 门店选择弹出层
  public storeWinShow: boolean = false;

  public shopId: string = '';
  public token: string = null;
  public data: any = { 1: {}, 2: {}, 3: {}, 4: {} };
  public points: any = { 1: {}, 2: {}, 3: {}, 4: {} };
  private _el: any;
  private _renderer: Renderer;

  constructor(
    private router: Router,
    private route: ActivatedRoute,
    public el: ElementRef,
    public renderer: Renderer,
    private dAPi: DefaultApi,
    private cs: CommonService,
    private ss: StoreService,
    private sApi: ShopApi) {
    this._el = el.nativeElement;
    this._renderer = renderer;
  }



  startX: number = 0;
  startY: number = 0;
  endX: number = 0;
  endY: number = 0;
  lastScrollDistance: number = 0;

  minTranslate() {
    return 0;
  };
  maxTranslate() {
    return 1137;
  };

  public ngOnInit() {
    this.lastScrollDistance = 0;
    this.token = localStorage.getItem('token') || '';
    this.getMyStores();
    this.slider = new Swiper('.swiper-container', {
      touchMoveStopPropagation: true,
      slidesPerView: 1,
      direction: 'vertical',
      mousewheelControl: true,
      mousewheelReleaseOnEdges: true,
      mousewheelSensitivity: 0.9,
      passiveListeners: true,
      //   onTouchStart: (swiper, event) => {
      //     if (swiper.activeIndex + 1 === 2) {
      //       let touch = event.changedTouches[0];
      //       this.startX = touch.pageX;
      //       this.startY = touch.pageY;
      //     }
      //   },
      //   onTouchMove: (swiper, event) => {
      //     if (swiper.activeIndex + 1 === 2) {
      //       //   console.log(swiper, event);
      //       let touch = event.changedTouches[0];
      //       this.endX = touch.pageX;
      //       this.endY = touch.pageY;
      //       //判断移动的点,1为手指向下滑动,-1为手指向上滑动
      //       let scrollDirection = (this.endY - this.startY) > 0 ? 1 : -1;
      //       //判断移动的点,1为手指向右滑动,-1为手指向左滑动
      //       let scrollTranslation = (this.endX - this.startX) > 0 ? 1 : -1;
      //       //计算滑动距离
      //       let scrollDistance = Math.abs(this.endY - this.startY);
      //
      //
      //       if(scrollDirection===1){
      //           this.lastScrollDistance = this.lastScrollDistance + scrollDistance;
      //       }else{
      //           this.lastScrollDistance = -(this.lastScrollDistance-scrollDistance);
      //       }
      //     //   let newTranslate = Math.min(this.lastScrollDistance, 1200);
      //     console.log(Math.min(this.lastScrollDistance, 1200), scrollDistance);
      //
      //       document.querySelector('.test')['style'] =
      //         `transform:translate3d(0px, ${this.lastScrollDistance}px, 0px);`;
      //     }
      //   },
      onSlideChangeEnd: (swiper) => {
        this.getList((swiper.activeIndex + 1) % 5, 1, this.shopId);
        // if (swiper.activeIndex + 1 === 2) {
        //   swiper.lockSwipes();
        // } else {
        //   //   swiper.unlockSwipes();
        // }
      }
    });

    // let startScroll, touchStart, touchCurrent;
    // this.slider.slides.on('touchstart', (e) => {
    //   // startScroll = this;
    //   // touchStart = e.targetTouches[0].pageY;
    // }, true);
    // this.slider.slides.on('touchmove', (e) => {
    //   // touchCurrent = e.targetTouches[0].pageY;
    //   // let touchesDiff = touchCurrent - touchStart;
    //   // let slide = this;
    //   // let onlyScrolling =
    //   //   (slide.scrollHeight > slide.offsetHeight) && //allow only when slide is scrollable
    //   //   (
    //   //     (touchesDiff < 0 && startScroll === 0) || //start from top edge to scroll bottom
    //   //     (touchesDiff > 0 && startScroll === (slide.scrollHeight - slide.offsetHeight)) || //start from bottom edge to scroll top
    //   //     (startScroll > 0 && startScroll < (slide.scrollHeight - slide.offsetHeight)) //start from the middle
    //   //   );
    //   //   console.log(onlyScrolling,slide.scrollHeight - slide.offsetHeight,startScroll,slide);
    //   // if (onlyScrolling) {
    //   //   e.stopPropagation();
    //   // }
    // }, true);
    this.getList(1, 1, this.shopId);

  }
  public ngOnDestroy() {
    this.slider = undefined;
  }

  public initEcharts(cur, option) {
    // 设置色彩主题模版
    echarts.registerTheme('my', {
      color: this.colors,
      graph: {
        color: this.colors
      }
    });
    let myChart = echarts.init(document.querySelector('.scatter-load' + cur), 'my');
    myChart.setOption(option);
  }

  public getList(cur = 1, size = 1, id = '') {
    this.dAPi.diagramsGetReportDetail4IndustryUserPost(cur, size, id).subscribe((res) => {
      if (res.meta.code === 200) {
        this.data[cur] = res.data[0];
        this.points[cur] = {};
        this.data[cur].points.forEach((val, i) => {
          if (this.points[cur][val.groupId]) {
            this.points[cur][val.groupId].push(val);
          } else {
            this.points[cur][val.groupId] = [val];
          }
        });

        let height = this._el.clientHeight - this._el.querySelector('.report-points').clientHeight - 270;
        this._el.querySelector('.scatter-load' + cur).style.height = `${height}px`;
        this.initEcharts(cur, this.data[cur].option);

      } else {
        console.error(res.error['msg']);
      }
    });
  }

  /**
   * 前进到下一屏
   *
   *
   * @memberOf ReportComponent
   */
  public onGotoNextSlide() {
    this.slider && this.slider.slideNext();
  }

  /**
   * 显示主菜单
   *
   *
   * @memberOf ReportComponent
   */
  public onShowMenu() {
    this.menu.show = true;
  }

  /**
   * 显示选择门店弹出层
   *
   *
   * @memberOf SubAccountFormComponent
   */
  public onShowStores() {
    this.storeWinShow = true;
  }

  /**
   * 选择门店 - 确定
   *
   * @param {any} evt
   *
   * @memberOf SubAccountFormComponent
   */
  public onSelectStoreOkey(evt) {
    let checked = this.stores.filter((item) => item.checked);
    this.shopId = _.map(checked, 'id').join(',');
    this.createShopStr();
    this.getList(1, 1, this.shopId);
    this.storeWinShow = false;
  }

  /**
   * 选择门店 - 取消
   *
   * @param {any} evt
   *
   * @memberOf SubAccountFormComponent
   */
  public onSelectStoreCancel(evt) {
    this.createShopStr();
    this.storeWinShow = false;
  }

  /**
   * 获取门店列表
   *
   * @private
   *
   * @memberOf SubAccountFormComponent
   */
  private getMyStores() {
    this.sApi.shopCarMobileMyshopGet(this.token).subscribe((data) => {
      if (data.meta.code === 200) {
        this.stores = this.formatStores(data.data);
        this.createShopStr();
      }
    }, (err) => console.error(err));
  }

  /**
   * 格式化门店
   *
   * @private
   * @param {any} stores
   * @returns {MxStoreResponseItem[]}
   *
   * @memberOf SubAccountFormComponent
   */
  private formatStores(stores): MxStoreResponseItem[] {
    return stores.map((item) => {
      item.checked = true;
      return item;
    });
  }

  /**
   * 创建数据源字符串
   *
   * @private
   * @returns
   *
   * @memberOf SubAccountFormComponent
   */
  private createShopStr() {
    if (this.shopId === '') {
      this.shopStr = '';
      this.stores = this.formatStores(this.stores);
      return;
    }
    let ids = this.shopId.split(',');
    this.stores.forEach((item) => {
      item.checked = _.includes(ids, String(item.id)) ? true : false;
    });
    let checkeds = this.stores.filter((item) => item.checked);
    this.shopStr = checkeds.length > 1 ? `${checkeds[0].name}等${checkeds.length}家门店` : `${checkeds[0].name}`;
  }

}
