import {
  Component,
  OnInit,
  OnDestroy
} from '@angular/core';
import {  Router, ActivatedRoute } from '@angular/router';
import * as _ from 'lodash';
import { CommonService, StoreService } from 'services';
import { ShopApi, MyShopResponseItem } from 'client';

@Component({
  selector: 'store-list',
  templateUrl: './list.component.html',
  styles: [require('./list.component.scss')],
  providers: [CommonService, StoreService, ShopApi]
})
export class StoreListComponent implements OnInit {
  public menu = {
    show: false
  };
  public listLoading: boolean = false;
  public lists: MyShopResponseItem[] = [];
  public qrStore: MyShopResponseItem = undefined;
  public isSub: number = 0;
  private token: string = '';

  constructor(
    private router: Router,
    private route: ActivatedRoute,
    private cs: CommonService,
    private ss: StoreService,
    private sApi: ShopApi
  ) {

  }

  public ngOnInit() {
    this.token = localStorage.getItem('token');
    this.getMyStores();
    this.isSub = Number(localStorage.getItem('isSub'));
  }

  /**
   * 显示主菜单
   * 
   * 
   * @memberOf ReportComponent
   */
  public onShowMenu() {
    this.menu.show = true;
  }

  /**
   * 编辑选中的门店
   * 
   * @param {any} store
   * 
   * @memberOf StoreListComponent
   */
  public onEditStore(store) {
    this.cs.gotoStoreEditPage(this.router, store.id);
  }

  /**
   * 打开二维码窗口
   * 
   * @param {any} store
   * @param {any} evt
   * 
   * @memberOf StoreListComponent
   */
  public onShowStoreQr(store, evt) {
    evt.stopPropagation();
    this.qrStore = store;
  }

  /**
   * 关闭二维码窗口
   * 
   * 
   * @memberOf StoreListComponent
   */
  public onCloseCodeWin() {
    this.qrStore = undefined;
  }

  /**
   * 添加新门店
   * 
   * 
   * @memberOf StoreListComponent
   */
  public onAddNewOne() {
    this.cs.gotoCreatePage(this.router, 'store');
  }

  private getMyStores() {
    this.listLoading = true;
    this.sApi.shopCarMobileMyshopGet(this.token).subscribe((data) => {
      if (data.meta.code === 200) {
        this.lists = data.data;
      } else {
        this.cs.responseErrorHandler(data, true, this.router);
      }
    }, (err) => console.error(err), () => {
      this.listLoading = false;
    });
  }

}
