import {
  Component,
  OnInit,
  OnDestroy,
  Input,
  Output,
  EventEmitter
} from '@angular/core';
import {  Router, ActivatedRoute } from '@angular/router';
import * as _ from 'lodash';
import { CommonService, StoreService } from 'services';
interface Shop {
  id: string | number;
  name: string;
  provinceId: string | number;
  cityId: string | number;
  address: string;
  manager: string;
  tel: string;
  serviceType: string;

}

import { MxStore } from 'interfaces';


@Component({
  selector: 'store-form',
  templateUrl: './store-form.component.html',
  styles: [require('./store-form.component.scss')],
  providers: [CommonService, StoreService]
})
export class StoreFormComponent implements OnInit {
  @Input() public store: MxStore;
  @Output() public onError: EventEmitter<string> = new EventEmitter();

  public serviceLists: any[] = [];
  public provinceList: any[] = [];
  public cityList: any[] = [];

  constructor(private router: Router, private route: ActivatedRoute, private cs: CommonService, private ss: StoreService) {

  }

  public ngOnInit() {
    // 初始化服务类型
    // this.initServiceList(this.ss.getStoreServiceList());
  }

  /**
   * 初始化服务项目
   * 为服务项目添加`checked`属性
   * 
   * @private
   * @param {any} services
   * 
   * @memberOf StoreFormComponent
   */
  private initServiceList(services) {
    this.serviceLists = services;
    this.serviceLists.forEach( (item) => item.checked = false );
  }

  /**
   * 门店 - 服务类型发生变化
   * 
   * @param {any} evt
   * 
   * @memberOf StoreFormComponent
   */
  private onChangeServiceIds(evt) {
      this.store.serviceType = evt;
      this.onError.emit('');
  }

  /**
   * 表单 - 输入型字段获取焦点
   * 
   * @private
   * 
   * @memberOf StoreFormComponent
   */
  private onFieldFocus() {
    this.onError.emit('');
  }

  private onAddressChange(evt) {
      this.onError.emit('');
      if (evt) {
          this.store.provinceId = evt.province;
          this.store.cityId = evt.city;
      }
  }
}
