import { Component, OnInit, OnDestroy } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import * as _ from 'lodash';
import { CommonService, SubAccountService, MxUtilService } from 'services';
import { MxSubAccount } from 'interfaces';
import { UserApi, ShopApi, MyShopResponseItem } from 'client';
import { Md5 } from 'ts-md5/dist/md5';

@Component({
  selector: 'sub-account-add',
  templateUrl: './add.component.html',
  styles: [require('./add.component.scss')],
  providers: [SubAccountService]
})
export class SubAccountAddComponent {
  public menu = {
    show: false
  };

  // 处理 iphone 手机浏览器 fixed 超不出顶部bug
  public showShopSelect: boolean = false;

  private account: MxSubAccount;
  private errorMsg: string = '';
  private submitting: boolean = false;

  constructor(
    private router: Router,
    private route: ActivatedRoute,
    private cs: CommonService,
    private sas: SubAccountService,
    private mus: MxUtilService,
    private uApi: UserApi
  ) {
    this.account = this.sas.getDefaultSubAccountValue();
  }

  public onVisibleSelectShop(evt) {
    console.log('shop win: ', evt);
    this.showShopSelect = evt;
  }

  private onErrorMsg(evt) {
    this.errorMsg = evt;
  }

  /**
   * 保存字段信息
   * 
   * @private
   * @returns 
   * 
   * @memberOf SubAccountAddComponent
   */
  private onSave() {
    if (this.submitting) { return; }
    if (!this.validateFormInfo()) { return; }
    this.submitting = true;
    this.createPassword();
    let { mobile, shopId, password, passwordMD5, name } = this.formatSubAccountData(this.account);
    this.uApi.userCarMobileAccountCreatePost(mobile, `[${shopId}]`, password, passwordMD5, name).subscribe((data) => {
      if (data.meta.code === 200) {
        this.gotoSubAccountListPage();
      } else {
        if (data.error && data.error.message) {
          this.errorMsg = this.cs.responseErrorHandler(data, false, this.router);
        }
      }
    }, (err) => console.error(err), () => {
      this.submitting = false;
    });
  }

  /**
   * 验证表单字段
   * 
   * @private
   * @returns {boolean} 
   * 
   * @memberOf StoreAddComponent
   */
  private validateFormInfo(): boolean {
    let { name, mobile, shopId } = this.account;

    if (this.mus.isEmptyString(mobile)) {
      this.errorMsg = '登录账号不能为空';
      return false;
    }
    if (!this.mus.isPhoneNumber(mobile)) {
      this.errorMsg = '请输入正确的手机号码';
      return false;
    }
    if (this.mus.isEmptyString(shopId)) {
      this.errorMsg = '请选择门店';
      return false;
    }
    this.errorMsg = '';
    return true;
  }

  /**
   * 格式化提交的账户数据
   * 
   * @private
   * @param {MxSubAccount} account 
   * @returns 
   * 
   * @memberOf SubAccountAddComponent
   */
  private formatSubAccountData(account: MxSubAccount) {
    return {
      name: account.name.trim(),
      shopId: account.shopId.trim(),
      mobile: account.mobile.trim(),
      password: account.password.trim(),
      passwordMD5: account.passwordMD5.trim()
    };

  }

  /**
   * 返回门店列表页
   * 
   * @private
   * 
   * @memberOf StoreAddComponent
   */
  private gotoSubAccountListPage() {
    this.cs.gotoListPage(this.router, 'subaccount');
  }

  /**
   * 生成密码 6位
   * 
   * @private
   * 
   * @memberOf SubAccountFormComponent
   */
  private createPassword() {
    this.account.password = Math.random().toString(16).slice(2, 8);
    this.account.passwordMD5 = Md5.hashStr(this.account.password, false).toString();
  }

}
