import {
  Component,
  OnInit,
  OnDestroy,
  Input,
  Output,
  EventEmitter
} from '@angular/core';
import {  Router, ActivatedRoute } from '@angular/router';
import * as _ from 'lodash';
import { CommonService, StoreService } from 'services';
import { MxSubAccount, MxStoreResponseItem } from 'interfaces';
import { ShopApi } from 'client';

@Component({
  selector: 'sub-account-form',
  templateUrl: './form.component.html',
  styles: [require('./form.component.scss')],
  providers: [ StoreService]
})
export class SubAccountFormComponent implements OnInit {
  public shopStr: string = '';
  public stores: MxStoreResponseItem[] = [];
  @Output() public onError: EventEmitter<string> = new EventEmitter();
  @Output() public onVisible: EventEmitter<boolean> = new EventEmitter();
  // 门店选择弹出层
  // public storeWinShow: boolean = false;
  public _storeWinShow: boolean = false;
  set storeWinShow(value: boolean) {
    this.onVisible.emit(value);
    this._storeWinShow = value;
  }
  get storeWinShow() {
    return this._storeWinShow;
  }
  private _account: MxSubAccount;
  @Input() set account(value: MxSubAccount) {
    if (this.stores.length === 0) {
      this.token = localStorage.getItem('token') || '';
      this.getMyStores();
    } else {
      setTimeout(() => { this.createShopStr(); }, 100);
    }
    this._account = value;
  }
  get account() {
    return this._account;
  }

  private token: string = '';

  constructor(
    private router: Router,
    private route: ActivatedRoute,
    private cs: CommonService,
    private ss: StoreService,
    private sApi: ShopApi
  ) {

  }

  public ngOnInit() {
    this.token = localStorage.getItem('token') || '';
  }

  /**
   * 显示选择门店弹出层
   * 
   * 
   * @memberOf SubAccountFormComponent
   */
  public onShowStores() {
    this.storeWinShow = true;
    this.onError.emit('');
  }

  /**
   * 选择门店 - 确定
   * 
   * @param {any} evt 
   * 
   * @memberOf SubAccountFormComponent
   */
  public onSelectStoreOkey(evt) {
    let checked = this.stores.filter((item) => item.checked);
    this.account.shopId = _.map(checked, 'id').join(',');
    this.createShopStr();
    this.storeWinShow = false;
  }

  /**
   * 选择门店 - 取消
   * 
   * @param {any} evt 
   * 
   * @memberOf SubAccountFormComponent
   */
  public onSelectStoreCancel(evt) {
    this.createShopStr();
    this.storeWinShow = false;
  }

  /**
   * 表单 - 输入型字段获取焦点
   * 
   * @private
   * 
   * @memberOf StoreFormComponent
   */
  private onFieldFocus() {
    this.onError.emit('');
  }

  /**
   * 获取门店列表
   * 
   * @private
   * 
   * @memberOf SubAccountFormComponent
   */
  private getMyStores() {
    this.sApi.shopCarMobileMyshopGet(this.token).subscribe((data) => {
      if (data.meta.code === 200) {
        this.stores = this.formatStores(data.data);
        this.createShopStr();
      }
    }, (err) => console.error(err));
  }

  /**
   * 格式化门店
   * 
   * @private
   * @param {any} stores 
   * @returns {MxStoreResponseItem[]} 
   * 
   * @memberOf SubAccountFormComponent
   */
  private formatStores(stores): MxStoreResponseItem[] {
    return stores.map((item) => {
      item.checked = false;
      return item;
    });
  }

  /**
   * 创建数据源字符串
   * 
   * @private
   * @returns 
   * 
   * @memberOf SubAccountFormComponent
   */
  private createShopStr() {
    if (this.account.shopId === '') {
      this.shopStr = '';
      this.stores = this.formatStores(this.stores);
      return;
    }
    let ids = this.account.shopId.split(',');
    this.stores.forEach((item) => {
      item.checked = _.includes(ids, String(item.id)) ? true : false;
    });
    let checkeds = this.stores.filter((item) => item.checked);
    this.shopStr = checkeds.length > 1 ? `${checkeds[0].name}等${checkeds.length}家门店` : `${checkeds[0].name}`;
  }

}
