import {
  Component,
  OnInit,
  NgZone
} from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';

import { UserApi, CommonApi, User } from 'client';

// https://github.com/cotag/ts-md5
import { Md5 } from 'ts-md5/dist/md5';
import { Cookie } from 'ng2-cookies';

@Component({
  selector: 'user-find-pwd-set',
  templateUrl: './find-pwd-set.component.html',
  styleUrls: ['./find-pwd-set.component.scss'],
  providers: [UserApi, CommonApi, Md5]
})

export class UserFindPwdSetComponent implements OnInit {

  private submitting: boolean = false;
  private pwd: string = '';
  private checkPwd: string = '';
  private errorMsg: string = '';

  public constructor(private router: Router, private route: ActivatedRoute, private uApi: UserApi, private cApi: CommonApi) {

  }

  public ngOnInit() {

  }

  private onSave() {
    if (this.submitting) {
      return false;
    }
    this.submitting = true;
    if (!this.pwd) {
      this.errorMsg = '密码不能为空';
      this.submitting = false;
      return false;
    }
    if (/^(?![a-zA-z]+$)(?!\d+$)(?![!@#$%^&*]+$)(?![a-zA-z\d]+$)(?![a-zA-z!@#$%^&*]+$)(?![\d!@#$%^&*]+$)[a-zA-Z\d!@#$%^&*]+$/.test(this.pwd)) {
      this.errorMsg = '请输入由6~16位的英文字母,数字和符号组成的密码';
      this.submitting = false;
      return false;
    }
    if (this.pwd !== this.checkPwd) {
      this.errorMsg = '两次密码不一致';
      this.submitting = false;
      return false;
    }
    this.uApi.userUpdatePwdPost(Md5.hashStr(this.pwd, false).toString(), Md5.hashStr(this.checkPwd, false).toString(), this.route.snapshot.params['sign']).subscribe((res) => {
      this.submitting = false;
      if (res.meta.code === 200) {
        this.router.navigate(['/user/find/pwd/done']);
      } else {
        this.errorMsg = res.error.message;
      }
    });
  }

}
