import {
  Component,
  OnInit
} from '@angular/core';
import {  Router, ActivatedRoute } from '@angular/router';

import { UserApi, CommonApi, User } from 'client';
import { Md5 } from 'ts-md5/dist/md5';
// import { Cookie } from 'ng2-cookies';
import { CommonService } from 'services';

@Component({
  selector: 'user-login',
  templateUrl: './login.component.html',
  styleUrls: ['./login.component.scss'],
  providers: [CommonApi, Md5]
})
export class UserLoginComponent implements OnInit {

  public loginForm: any = {
    mobile: '',
    password: '',
    code: ''
  };
  public img: string;
  public uuid: string;
  public errorMsg: string = '';
  private submitting: boolean = false;

  public constructor(private router: Router, private uApi: UserApi, private cApi: CommonApi, private cs: CommonService) {
  }

  public ngOnInit() {
    this.onGetCodeImg();
  }

  public onGetCodeImg() {
    this.cApi.commonCaptchaBase64Post().subscribe((data) => {
      const resbody = data.json();
      if (resbody.meta.code === 200) {
        this.img = 'data:image/jpeg;base64,' + (resbody.data || '');
        this.uuid = data.headers.get('uuid');
        this.uApi.defaultHeaders.set('uuid', data.headers.get('uuid'));
      }
    });
  }

// http://www.thzhishu.com/manageredirect/dashboard/report/simulation/car

// http://www.thzhishu.com/manageredirect/user/login

  public onLogin() {
    if (this.submitting || !this.checkLoginInfo()) {
      return;
    }
    this.submitting = true;
    this.uApi.userLoginPost(this.loginForm.mobile, Md5.hashStr(this.loginForm.password, false).toString(), this.loginForm.code).subscribe((data) => {
      if (data.meta.code === 200) {
        this.setLocalStorage(data.data);
        if (data.data.type !== 2) {
          this.cs.gotoDevPage(this.router);
          return;
        }
        // 为Api接口服务设置 token 头
        this.cs.setHeardFieldForApi('token', data.data.token);

        if (data.data.isSub === 1) {
          // 子账号
          this.dealSubAccount(data.data);
          return;
        }
        // 主账户
        this.dealMainAccount(data.data);
      } else {
        if (data.error && data.error.message) {
          this.errorMsg = data.error.message;
          return;
        }
      }
    }, (err) => console.error(err), () => {
      this.submitting = false;
    });
  }

  public onFieldFocus() {
    this.errorMsg = '';
  }

  /**
   * 登录后 - 设置localStory
   * 
   * @private
   * @param {any} data 
   * 
   * @memberOf UserLoginComponent
   */
  private setLocalStorage(data) {
    if (data.pay === 0) {
      data.pay = 1;
    }
    // Cookie.set('token', data.token, 14);
    this.cs.setUserInfoToLocalStorage(data);
  }

  /**
   * 登录后 - 处理主账户
   * 
   * @private
   * @param {any} data 
   * @returns 
   * 
   * @memberOf UserLoginComponent
   */
  private dealMainAccount(data) {
    // 没有门店
    if (!data.shopId) {
      localStorage.removeItem('shopId');
      this.cs.gotoInitStorePage(this.router);
      return;
    }
    // 有id没支付
    if (data.pay === 1) {
      this.cs.gotoInitStorePage(this.router);
      return;
    }
    // 到报告中心页
    this.cs.gotoReportCenterPage(this.router);
  }

  /**
   * 登录后 - 处理子账号
   * 
   * @private
   * @param {any} data 
   * 
   * @memberOf UserLoginComponent
   */
  private dealSubAccount(data) {
    data.subStatus === 1 ? this.cs.gotoActiveSubAccountPage(this.router) : this.cs.gotoReportCenterPage(this.router);
  }

  private checkLoginInfo(): boolean {
    let mobile = this.loginForm.mobile = this.loginForm.mobile.trim();
    let pwd = this.loginForm.password = this.loginForm.password.trim();
    let code = this.loginForm.code = this.loginForm.code.trim();
    let mobileReg = /^(13[0-9]|15[012356789]|17[0135678]|18[0-9]|14[57])[0-9]{8}$/;
    if (mobile === '') {
      this.errorMsg = '手机号不能为空';
      return false;
    }
    if (!mobileReg.test(mobile)) {
      this.errorMsg = '请输入正确的手机号';
      return false;
    }
    if (pwd === '') {
      this.errorMsg = '密码不能为空';
      return false;
    }
    if (code === '') {
      this.errorMsg = '验证码不能为空';
      return false;
    }
    this.errorMsg = '';
    return true;
  }

}
