import { Component, OnInit, Input, Output, EventEmitter } from '@angular/core';
import { RegionProvinceList, CommonApi } from 'client';
import { StoreService, CommonDataService, CommonService } from 'services';
import * as _ from 'lodash';

@Component({
    selector: 'address-province-city',
    templateUrl: './address-province-city.component.html',
    styleUrls: ['./address-province-city.component.scss'],
    providers: [CommonApi, CommonService]
})
export class AddressProvinceCityComponent implements OnInit {
    public provinceList: RegionProvinceList[] = [];
    public cityList: RegionProvinceList[] = [];
    @Output() public onChange: EventEmitter<any> = new EventEmitter();
    @Input() private cityId: number | string = '';
    private _provinceId: number | string = '';
    @Input() set provinceId(value) {
        if (value === '') {
            this.cityId = '';
        } else {
            this.getCities(String(value));
        }
        this._provinceId = value;
    }
    get provinceId() {
        return this._provinceId;
    }

    constructor(private cs: CommonService, private cds: CommonDataService, private cApi: CommonApi) {
    }

    public ngOnInit() {
        this.getProvinces();
    }

    /**
     * 获取省份
     * 
     * @private
     * @returns
     * 
     * @memberOf AddressProvinceCityComponent
     */
    private getProvinces() {
        if (this.cds.provinceList.length) {
            this.provinceList = this.cds.provinceList;
            return;
        }
        this.cApi.commonRegionProvinceGet().subscribe((data) => {
            if (data.meta.code === 200) {
                this.provinceList = data.data;
                this.cds.provinceList = _.cloneDeep(data.data);
            } else {
                this.cs.responseErrorHandler(data);
            }
        }, (err) => console.error(err));
    }

    /**
     * 获取省份对应的城市
     * 
     * @private
     * @param {string} id
     * @returns
     * 
     * @memberOf AddressProvinceCityComponent
     */
    private getCities(id: string) {
        if (this.cds.cityListObj[id]) {
            this.cityList = this.cds.cityListObj[id];
            return;
        }
        this.cApi.commonRegionProvinceIdCityGet(Number(id)).subscribe((data) => {
            if (data.meta.code === 200) {
                this.cityList = data.data;
                this.cds.cityListObj[id] = _.cloneDeep(data.data);
            } else {
                this.cs.responseErrorHandler(data);
            }
        }, (err) => console.error(err));
    }

    private onChangeProvince(evt) {
        this.provinceId = evt;
        this.cityId = '';
        this.changeEmit();
    }

    private onChangeCity(evt) {
        this.cityId = evt;
        this.changeEmit();
    }

    private changeEmit() {
        this.onChange.emit({
            province: this.provinceId,
            city: this.cityId
        });
    }

}
