import { Component, OnInit, Input, Output, EventEmitter } from '@angular/core';
// import { Shop } from 'client';
import { StoreService } from 'services';
import * as _ from 'lodash';

interface Shop {
  id: string | number;
  name: string;
  provinceId: string | number;
  cityId: string | number;
  address: string;
  manager: string;
  tel: string;
  serviceType: string;

}

@Component({
    selector: 'store-service-type',
    templateUrl: './store-service-type.component.html',
    styleUrls: ['./store-service-type.component.scss'],

})
export class StoreServiceTypeComponent {
    @Output() public onChange: EventEmitter<any> = new EventEmitter();
    private serviceLists: any[] = [];
    private _serviceIds: string = '';
    @Input() set serviceIds(value: string) {
        value ? this.editServiceTypes(value) : this.initServiceList();
        this._serviceIds = value;
    }
    get serviceIds(): string {
        return this._serviceIds;
    }

    constructor(private ss: StoreService) {
        this.initServiceList();
    }

    /**
     * 选择服务项目
     * 
     * @param {any} service
     * @param {any} evt
     * 
     * @memberOf StoreServiceTypeComponent
     */
    public onChangeService(service, evt) {
        service.checked = evt;
        let idStr = this.serviceLists.filter((item) => item.checked).map((item) => item.id).join(',');
        this.onChange.emit(idStr);
    }

    /**
     * 初始化服务数组
     * 
     * @private
     * 
     * @memberOf StoreServiceTypeComponent
     */
    private initServiceList() {
        this.serviceLists = this.ss.getStoreServiceList();
        this.serviceLists.forEach( (item) => item.checked = false );
    }

    /**
     * 门店编辑时初始化服务数组
     * 
     * @private
     * @param {string} value
     * 
     * @memberOf StoreServiceTypeComponent
     */
    private editServiceTypes(value: string) {
        let types = value.split(',');
        this.serviceLists.forEach((item) => {
            item.checked = _.includes(types, String(item.id)) ? true : false;
        });
    }

}
