import { Component, OnInit, Output, EventEmitter, NgZone, Input } from '@angular/core';
import { Router, ActivatedRoute, NavigationEnd } from '@angular/router';
import { UserApi } from 'client';
import { CommonService } from 'services';
// import { Cookie } from 'ng2-cookies';
import { Md5 } from 'ts-md5/dist/md5';

@Component({
    selector: 'th-sms',
    templateUrl: './th-sms.component.html',
    styleUrls: ['./th-sms.component.scss'],
    providers: [UserApi, CommonService]
})
export class ThSmsComponent implements OnInit {
    @Input() public phone: string = '';
    @Input() public captcha: string = '';
    @Output() public onInput: EventEmitter<any> = new EventEmitter();
    @Output() public onError: EventEmitter<any> = new EventEmitter();
    public zone: any;
    public errorMsg: string = '';
    // 发短信
    public freezing: boolean = false;
    public freezeTimeout: any;
    public freezeTime: number = 60;
    public freezeBtnTxt: string = '获取验证码';
    // 协议
    public openProtocol: boolean = false;
    private submitting: boolean = false;
    private salt: string = 'thzs0708';
    constructor(private router: Router, private route: ActivatedRoute, private uApi: UserApi, private cs: CommonService) {
        this.zone = new NgZone({ enableLongStackTrace: false });
    }

    public ngOnInit() {

    }

    /**
     * 短信验证码 - 获取短信验证码
     * 
     * 
     * @memberOf UserRegistComponent
     */
    public getSmsCode() {

        // 是否处于冻结状态
        if (this.freezing) {
            return false;
        }

        // 检查手机号和图形验证码
        if (!this.checkMobileAndApatcha()) {
            return false;
        }
        // 创建60s计时器
        this.createFreezeTimer();
        let rnd = Math.random().toString(16).slice(2, 6);
        let sign = Md5.hashStr(this.phone + rnd + this.salt).toString();
        this.uApi.defaultHeaders.set('uuid', localStorage.getItem('uuid'));
        this.uApi.userPasswordSmsPost(this.phone, rnd, this.captcha, sign).subscribe((data) => {
            if (data.meta.code !== 200) {
                if (this.freezeTimeout) {
                    clearInterval(this.freezeTimeout);
                }
                if (data.error && data.error.message) {
                    this.errorMsg = data.error.message;
                    this.freezeBtnTxt = '重新发送';
                    this.freezing = false;
                    this.onError.next(data.error.message);
                }
            }
        }, (err) => console.error(err));
    }

    /**
     * 验证手机号和图形验证码
     * 
     * @private
     * @returns {boolean}
     * 
     * @memberOf UserRegistComponent
     */
    private checkMobileAndApatcha(): boolean {
        let mobile = this.phone = this.phone.trim();
        let captcha = this.captcha = this.captcha.trim();
        let mobileReg = /^(13[0-9]|15[012356789]|17[0135678]|18[0-9]|14[57])[0-9]{8}$/;
        if (mobile === '') {
            this.errorMsg = '手机号不能为空';
            this.onError.next(this.errorMsg);
            return false;
        }
        if (!mobileReg.test(mobile)) {
            this.errorMsg = '请输入正确的手机号';
            this.onError.next(this.errorMsg);
            return false;
        }
        if (captcha === '') {
            this.errorMsg = '验证码不能为空';
            this.onError.next(this.errorMsg);
            return false;
        }
        this.errorMsg = '';
        return true;
    }

    /**
     * 创建倒数计时器
     * 
     * @private
     * 
     * @memberOf UserRegistComponent
     */
    private createFreezeTimer() {
        this.freezing = true;
        this.freezeTime = 60;
        this.freezeBtnTxt = `${this.freezeTime}s`;
        this.freezeTimeout = window.setInterval(() => {
            this.zone.run(() => {
                if (this.freezeTime > 1) {
                    this.freezeTime--;
                    this.freezeBtnTxt = `${this.freezeTime}s`;
                } else {
                    this.freezeBtnTxt = `重新发送`;
                    this.freezing = false;
                    clearInterval(this.freezeTimeout);
                }
            });

        }, 1000);
    }
    private onChange(evt) {
        this.onInput.next(evt.target.value);
    }
}
