import { Component, Input, Output, OnInit, EventEmitter } from '@angular/core';
import {  Router, ActivatedRoute } from '@angular/router';
import { MyOrderData, OrderApi } from 'client';
import { MxUtilService, CommonService } from 'services';
import * as _ from 'lodash';

@Component({
    selector: 'win-apply-invoice',
    templateUrl: './win-apply-invoice.component.html',
    styleUrls: ['./win-apply-invoice.component.scss'],
    providers: [ MxUtilService, CommonService ]
})
export class WinApplyInvoiceComponent {
    public invoice: any = {
        id: '',
        invoiceTitle: '',
        linkman: '',
        tel: ''
    };
    @Output() public onOkey = new EventEmitter();
    @Output() public onCancel = new EventEmitter();
    @Input() public orderId: number;

    private errorMsg: string = '';
    private submitting: boolean = false;

    constructor(private router: Router, private mus: MxUtilService, private cs: CommonService, private oApi: OrderApi) {
    }

    /**
     * 点击取消或申请
     * 
     * @param {any} status 
     * 
     * @memberOf WinApplyInvoiceComponent
     */
    public onWarnSelect(status) {
        status ? this.saveInvoice() : this.onCancel.emit();
    }

    /**
     * 表单输入型字段获取焦点
     * 
     * 
     * @memberOf WinApplyInvoiceComponent
     */
    public onFieldFocus() {
        this.errorMsg = '';
    }

    /**
     * 验证表单各字段
     * 
     * @private
     * @returns {boolean} 
     * 
     * @memberOf WinApplyInvoiceComponent
     */
    private validateFormInfo(): boolean {
        let { invoiceTitle, linkman, tel } = this.invoice;
        if (this.mus.isEmptyString(invoiceTitle)) {
            this.errorMsg = '请输入发票抬头';
            return false;
        }
        if (this.mus.isEmptyString(linkman)) {
            this.errorMsg = '请输入联系人姓名';
            return false;
        }
        if (this.mus.isEmptyString(tel)) {
            this.errorMsg = '请输入联系电话';
            return false;
        }
        if (!(this.mus.isPhoneNumber(tel) || this.mus.isHandFreePhoneNumber(tel))) {
            this.errorMsg = '请输入有效的联系电话';
            return false;
        }
        this.errorMsg = '';
        return true;
    }

    /**
     * 保存发票信息
     * 
     * @private
     * @returns 
     * 
     * @memberOf WinApplyInvoiceComponent
     */
    private saveInvoice() {
        if (this.submitting) { return; }
        if (!this.validateFormInfo()) { return; }
        this.submitting = true;
        this.oApi.orderCarMobileIdInvoicePost(
            this.orderId,
            this.invoice.invoiceTitle.trim(),
            this.invoice.linkman.trim(),
            this.invoice.tel.trim()
        ).subscribe((data) => {
            if (data.meta.code === 200) {
                this.onOkey.emit();
            } else {
                this.cs.responseErrorHandler(data, true, this.router);
            }
        }, (err) => console.error(err), () => {
            this.submitting = false;
        });

        // setTimeout(() => {
        //     this.onOkey.emit();
        // }, 2000);

    }

}
