import { Injectable }  from '@angular/core';
import * as consts from 'consts';
import * as _ from 'lodash';
@Injectable()
export class StoreService {
    constructor() {}
    
    /**
     * 获取门店服务类型
     * 
     * @returns
     * 
     * @memberOf StoreService
     */
    public getStoreServiceList() {
        return _.cloneDeep(consts.SERVICE_LIST) || [];
    }

    /**
     * 获取门店服务的购买类型
     * 
     * @returns 
     * 
     * @memberOf StoreService
     */
    public getStoreBuyServiceList() {
        return _.cloneDeep(consts.BUY_SERVICE_LIST) || [];
    }

    /**
     * 通过money获取标题
     * 
     * @param {number} money 
     * @returns {string} 
     * 
     * @memberOf StoreService
     */
    public getStoreBuyServiceTitle(money: number): string {
        let item = this.getStoreBuyServiceItemByMoney(money);
        return item ? item.title : '';
    }

    /**
     * 通过金额获取购买服务类型的 key值
     * 
     * @param {number} money 
     * @returns {string} 
     * 
     * @memberOf StoreService
     */
    public getStoreBuyServiceKey(money: number): string {
        let item = this.getStoreBuyServiceItemByMoney(money);
        return item ? item.key : '';
    }

    /**
     * 通过金额获取购买服务类型
     * 
     * @param {number} money 
     * @returns 
     * 
     * @memberOf StoreService
     */
    public getStoreBuyServiceItemByMoney(money: number) {
        let list = _.cloneDeep(consts.BUY_SERVICE_LIST) || [];
        return list.filter((o) => o.money === money)[0];
    }

    /**
     * 获取默认门店值
     * 
     * @returns
     * 
     * @memberOf StoreService
     */
    public getDefaultStoreValue() {
        return _.cloneDeep(consts.STORE_DEFAULT);
    }
}
