import { Injectable }  from '@angular/core';
import * as consts from 'consts';
import * as _ from 'lodash';
@Injectable()
export class MxUtilService {
    constructor() {}
    
    /**
     * 检测手机号
     * 
     * @param {string} phone 
     * @returns {boolean} 
     * 
     * @memberOf MxUtilService
     */
    public isPhoneNumber(phone: string): boolean {
        return consts.REGEXP_PHONE.test(phone);
    }

    /**
     * 检测空字符串
     * 
     * @param {string} str 
     * @returns {boolean} 
     * 
     * @memberOf MxUtilService
     */
    public isEmptyString(str: string): boolean {
        return str.trim() === '';
    }

    /**
     * 检测固定电话
     * 
     * @param {string} phone 
     * @returns {boolean} 
     * 
     * @memberOf MxUtilService
     */
    public isHandFreePhoneNumber(phone: string): boolean {
        return consts.HAND_FREE_PHONE_NUMBER.test(phone);
    }

    /**
     * 检测字符串的长度是否小于给定的长度
     * 
     * @param {string} str 
     * @param {number} len 
     * @returns {boolean} 
     * 
     * @memberOf MxUtilService
     */
    public isTooShort(str: string, len: number): boolean {
        return str.trim().length < len;
    }

    /**
     * 检测密码
     * 
     * @param {string} str 
     * @returns {boolean} 
     * 
     * @memberOf MxUtilService
     */
    public isPassword(str: string): boolean {
        return consts.REGEXP_PASSWORD.test(str.trim());
    }

    /**
     * 判断两个字符串相等
     * 
     * @param {string} str1 
     * @param {string} str2 
     * @returns {boolean} 
     * 
     * @memberOf MxUtilService
     */
    public isEqualString(str1: string, str2: string): boolean {
        return str1.trim() === str2.trim();
    }
}
