import { Component, OnInit } from '@angular/core';
import {  Router, ActivatedRoute } from '@angular/router';
import * as _ from 'lodash';
import { CommonService, StoreService } from 'services';
import { UserApi, CommonApi, ShopApi, OrderApi, PayApi, User, MyOrderData } from 'client';
import { CAN_WX_PAY, APP_PROJECT_HOST } from 'consts';

// const WeixinJSBridge = window['WeixinJSBridge'];

@Component({
  selector: 'storeorder',
  templateUrl: './storeorder.component.html',
  styleUrls: ['./storeorder.component.scss'],
  providers: [StoreService]
})
export class StoreorderComponent implements OnInit {

  public storeOrderInfo: MyOrderData;
  public shopId: number;
  public pay: number;
  public shopOrderId: number;
  public showVcodeWin: boolean = false;
  public source: string = '';
  public buyServiceName: string = '';

  // wx
  public openId: any;
  public orderId: any;
  public wxData: any = {
      appId: '',
      timeStamp: '',
      nonceStr: '',
      package: '',
      signType: '',
      paySign: ''
  };
  public urlState: any = {};
  public urlParams: any;

  // 订单信息窗口
  public showOrderInfoWin: boolean = false;

  private token: string = '';

  constructor(
    private router: Router,
    private route: ActivatedRoute,
    private oApi: OrderApi,
    private cs: CommonService,
    private ss: StoreService,
    private pApi: PayApi,
    private uApi: UserApi
  ) {

  }

  public ngOnInit() {
    // let shopid = localStorage.getItem('shopId');
    // let paystatus = localStorage.getItem('shopPay');
    // let shopOrderId = localStorage.getItem('shopOrderId');
    this.token = localStorage.getItem('token');
    this.route.queryParams.subscribe((data) => {
        this.urlParams = data;
        if (data['openId']) {
            this.openId = data['openId'];
        }
        // if (data['params']) {
        //     this.urlState = this.parseUrlFieldPrams(data['params']);
        // }
        if (data['orderId']) {
          this.orderId = +data['orderId'];
        }
        if (data['shopId']) {
          this.shopId = +data['shopId'];
        }
        if (data['source']) {
          this.source = data['source'];
        }
    });

    if (!this.token) {
      this.cs.gotoLoginPage(this.router);
      return;
    }
    // this.shopId = shopid === null ? undefined : Number(shopid);
    // this.pay = paystatus === null ? undefined : Number(paystatus);
    // this.shopOrderId = shopOrderId === null ? undefined : Number(shopOrderId);
    if (this.orderId) {
      this.getOrderInfo(this.orderId);
    }
  }

  

  /**
   * 订单 - 取消订单
   * 
   * @param {any} id
   * 
   * @memberOf StoreInitComponent
   */
  public onCancelOrder(id) {
    this.oApi.orderCarMobileIdDeleteDelete(String(id)).subscribe((data) => {
      // if (data.meta.code === 200) {
      //   this.storeOrderInfo = _.cloneDeep(orderDefault);
      //   this.showOrderInfoWin = false;
      //   localStorage.removeItem('shopOrderId');
      // } else {
      //   this.cs.responseErrorHandler(data);
      // }
    }, (err) => console.error(err));
  }

  /**
   * 订单 - 支付订单
   * 
   * @param {any} id
   * 
   * @memberOf StoreInitComponent
   */
  public onPayOrder() {
    if (CAN_WX_PAY) {
      this.pApi.paymentWeChatPayPost(Number(this.orderId), String(this.openId), 1).subscribe((data) => {
          if (data.meta.code === 200) {
              this.wxData.appId = data.data.appId;
              this.wxData.package = data.data.package;
              this.wxData.nonceStr = data.data.nonceStr;
              this.wxData.timeStamp = data.data.timeStamp + '';
              this.wxData.signType = data.data.signType;
              this.wxData.paySign = data.data.paySign;

              this.callWxPay();
          } else {
              // alert('ajax error');
              this.cs.responseErrorHandler(data, true, this.router);
          }
      }, (err) => console.error(err));
    } else {
      this.pApi.paymentPayTestPost(this.orderId, 1).subscribe((data) => {
        if (data) {
          this.uApi.userUserInfoTokenGet(this.token).subscribe((dd) => {
            if (dd.meta.code === 200) {
              localStorage.setItem('shopPay', String(dd.data.pay));
              this.gotoSourcePage();
            } else {
              this.cs.responseErrorHandler(data, true, this.router);
            }
          }, (err) => console.error(err));
        }
      }, (err) => console.error(err));
    }
  }

  // 临时支付 假的
  // public onPayOrderTemp(orderid, shopid) {
  //   this.oApi.paymentImPayGet(Number(orderid), Number(shopid)).subscribe((data) => {
  //     if (data.meta.code === 200) {
  //       localStorage.setItem('shopPay', '2');
  //       this.showOrderInfoWin = false;
  //       this.showVcodeWin = true;
  //     } else {
  //       this.cs.responseErrorHandler(data, false, this.router);
  //     }
  //   }, (err) => console.error(err));
  // }

  private gotoSourcePage() {
    switch (this.source) {
      case 'storeInit':
        // this.cs.gotoReportCenterPage(this.router);
        window.location.href = `${ APP_PROJECT_HOST }/dashboard/report/store`;
        break;
      case 'orderList':
        // this.cs.gotoListPage(this.router, 'order');
        window.location.href = `${ APP_PROJECT_HOST }/dashboard/order/list`;
        break;
      case 'storeAdd':
        // this.cs.gotoListPage(this.router, 'store');
        window.location.href = `${ APP_PROJECT_HOST }/dashboard/store/list`;
        break;
      default:
        window.location.href = `${ APP_PROJECT_HOST }/dashboard/report/store`;
    }
  }

  /**
   * 编辑初始门店时，获取订单信息
   * 
   * @private
   * @param {any} orderId
   * 
   * @memberOf StoreInitComponent
   */
  private getOrderInfo(orderId) {
    this.oApi.orderCarMobileOrderIdGet(Number(orderId)).subscribe((data) => {
      if (data.meta.code === 200 && data.data) {
        this.storeOrderInfo = data.data;
        this.buyServiceName = this.ss.getStoreBuyServiceTitle(this.storeOrderInfo.money);
        this.showOrderInfoWin = true;
      } else {
        this.cs.responseErrorHandler(data, false, this.router);
      }
    }, (err) => console.error(err));
  }

  // 调起微信支付面板
  private callWxPay() {
    if (typeof window['WeixinJSBridge'] === 'undefined') {
        if ( document.addEventListener ) {
            document.addEventListener('WeixinJSBridgeReady', this.jsApiCall.bind(this), false);
        }else if (document['attachEvent']) {
            document['attachEvent']('WeixinJSBridgeReady', this.jsApiCall);
            document['attachEvent']('onWeixinJSBridgeReady', this.jsApiCall);
        }
    } else {
        this.jsApiCall();
    }
  }
  private jsApiCall() {
    window['WeixinJSBridge'].invoke(
        'getBrandWCPayRequest',
        this.wxData,
        (res) => {
            if (res.err_msg === 'get_brand_wcpay_request:ok' ) {
                localStorage.setItem('shopPay', '2');
                this.gotoSourcePage();
            }
        }
    );
  }

  /**
   * 解析参数字段
   * 
   * @private
   * @param {string} parmas
   * @returns
   * 
   * @memberOf StoreInitOrderComponent
   */
  private parseUrlFieldPrams(parmas: string) {
    let paramsObj = parmas.split('@');
    let ret: any = {};
    paramsObj.forEach((val) => {
        let temp = val.split('-');
        ret[temp[0]] = temp[1];
    });
    return ret;
  }

}
